from loguru import logger

from upswingutil.db import Firestore
from upswingutil.schema import AlvieQRGenerateorModels, ResponseDict


def alvie_qr_generator(qr_data: AlvieQRGenerateorModels):
    response = ResponseDict(status=False, message="Init Message", data={})
    try:
        ref = Firestore('alvie').write_doc_auto_id(
            f"Organizations/{qr_data.orgId}/properties/{qr_data.hotelId}/integrations/qrCodes/codes", qr_data.data)
        ref_doc = ref[1].get()
        if ref_doc.exists:
            response.data = {'id': ref_doc.id}
            response.status = True
            response.message = "Successfully generated the QR Code"
    except Exception as e:
        logger.error(f"Error in generating the QR for {qr_data.orgId} - {qr_data.hotelId} - {qr_data.data}")
        logger.error(e)
        response.message = f"Error occurred - {e.__str__()}"
    finally:
        return response.dict()



from typing import List, Optional

from pydantic.main import BaseModel


class BookingsModel(BaseModel):
    hotelId: str
    reservationId: str
    roomId: str


class GuestUserProfileModel(BaseModel):
    # hotelId: str = "11282"
    profileSource: str = 'manual'
    firstName: str
    lastName: str
    email: str
    mobile: str
    bookings: Optional[List[BookingsModel]] = None



import json
import logging
import unittest

import firebase_admin
from firebase_admin import credentials
from loguru import logger

import upswingutil as ul

from upswingutil.resource import access_secret_version
from upswingutil.resource.qr_codes import alvie_qr_generator
from upswingutil.schema import AlvieQRGenerateorModels


class TestQR_Generation(unittest.TestCase):
    ul.G_CLOUD_PROJECT = 'aura-staging-31cae'
    # ul.G_CLOUD_PROJECT = 'alvie-development'
    ul.ENCRYPTION_SECRET = access_secret_version(ul.G_CLOUD_PROJECT, 'ENCRYPT_SECRET_KEY', 1)
    ul.MONGO_URI = access_secret_version(ul.G_CLOUD_PROJECT, 'MONGOURI', '5')
    ul.LOG_LEVEL_VALUE = logging.DEBUG

    print('Initializing default firebase app')
    cred = json.loads(
        access_secret_version(ul.G_CLOUD_PROJECT, 'Firebase-Aura', '1'))
    cred = credentials.Certificate(cred)
    firebase_admin.initialize_app(cred)

    print('Initializing alvie firebase app')
    cred = json.loads(
        access_secret_version(ul.G_CLOUD_PROJECT, 'Firebase-Alvie', '3'))
    cred = credentials.Certificate(cred)
    firebase_admin.initialize_app(cred, name='alvie')

    def test_alvie_qr(self):
        data = AlvieQRGenerateorModels(
            orgId="11281",
            hotelId="11282",
            data={"data": "test"}
        )
        d = alvie_qr_generator(data)
        logger.info(d)